@@ -3,6 +3,7 @@
  *
  * pidgin-sipe
  *
+ * Copyright (C) 2010 SIPE Project <http://sipe.sourceforge.net/>
  * Copyright (C) 2009 pier11 <pier11@operamail.com>
  *
  * Implements Remote Call Control (RCC) feature for
@@ -35,9 +36,12 @@
 #include "sipe-common.h"
 #include "sipmsg.h"
 #include "sip-csta.h"
-#include "sip-sec.h"
+#include "sip-transport.h"
 #include "sipe-backend.h"
+#include "sipe-core.h"
+#include "sipe-core-private.h"
 #include "sipe-dialog.h"
+#include "sipe-schedule.h"
 #include "sipe-utils.h"
 #include "sipe-xml.h"
 #include "sipe.h"
@@ -182,10 +186,11 @@ sip_tel_uri_denormalize(const gchar *tel_uri)
 }
 
 static void
-sip_csta_initialize(struct sipe_account_data *sip,
+sip_csta_initialize(struct sipe_core_private *sipe_private,
 		    const gchar *line_uri,
 		    const gchar *server)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	if(!sip->csta) {
 		sip->csta = g_new0(struct sip_csta, 1);
 		sip->csta->line_uri = g_strdup(line_uri);
@@ -197,7 +202,7 @@ sip_csta_initialize(struct sipe_account_data *sip,
 
 /** get CSTA feautures's callback */
 static gboolean
-process_csta_get_features_response(SIPE_UNUSED_PARAMETER struct sipe_account_data *sip,
+process_csta_get_features_response(SIPE_UNUSED_PARAMETER struct sipe_core_private *sipe_private,
 				   struct sipmsg *msg,
 				   SIPE_UNUSED_PARAMETER struct transaction *trans)
 {
@@ -215,8 +220,9 @@ process_csta_get_features_response(SIPE_UNUSED_PARAMETER struct sipe_account_dat
 
 /** get CSTA feautures */
 static void
-sip_csta_get_features(struct sipe_account_data *sip)
+sip_csta_get_features(struct sipe_core_private *sipe_private)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	gchar *hdr;
 	gchar *body;
 
@@ -233,24 +239,23 @@ sip_csta_get_features(struct sipe_account_data *sip)
 		SIP_SEND_CSTA_GET_CSTA_FEATURES,
 		sip->csta->line_uri);
 
-	send_sip_request(sip->gc,
-			 "INFO",
-			 sip->csta->dialog->with,
-			 sip->csta->dialog->with,
-			 hdr,
-			 body,
-			 sip->csta->dialog,
-			 process_csta_get_features_response);
+	sip_transport_info(sipe_private,
+			   hdr, 
+			   body,
+			   sip->csta->dialog,
+			   process_csta_get_features_response);
 	g_free(body);
 	g_free(hdr);
 }
 
 /** Monitor Start's callback */
 static gboolean
-process_csta_monitor_start_response(struct sipe_account_data *sip,
+process_csta_monitor_start_response(struct sipe_core_private *sipe_private,
 				    struct sipmsg *msg,
 				    SIPE_UNUSED_PARAMETER struct transaction *trans)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
+
 	SIPE_DEBUG_INFO("process_csta_monitor_start_response:\n%s", msg->body ? msg->body : "");
 
 	if (!sip->csta) {
@@ -277,8 +282,9 @@ process_csta_monitor_start_response(struct sipe_account_data *sip,
 
 /** Monitor Start */
 static void
-sip_csta_monitor_start(struct sipe_account_data *sip)
+sip_csta_monitor_start(struct sipe_core_private *sipe_private)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	gchar *hdr;
 	gchar *body;
 
@@ -295,22 +301,20 @@ sip_csta_monitor_start(struct sipe_account_data *sip)
 		SIP_SEND_CSTA_MONITOR_START,
 		sip->csta->line_uri);
 
-	send_sip_request(sip->gc,
-			 "INFO",
-			 sip->csta->dialog->with,
-			 sip->csta->dialog->with,
-			 hdr,
-			 body,
-			 sip->csta->dialog,
-			 process_csta_monitor_start_response);
+	sip_transport_info(sipe_private,
+			   hdr,
+			   body,
+			   sip->csta->dialog,
+			   process_csta_monitor_start_response);
 	g_free(body);
 	g_free(hdr);
 }
 
 /** Monitor Stop */
 static void
-sip_csta_monitor_stop(struct sipe_account_data *sip)
+sip_csta_monitor_stop(struct sipe_core_private *sipe_private)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	gchar *hdr;
 	gchar *body;
 
@@ -332,27 +336,27 @@ sip_csta_monitor_stop(struct sipe_account_data *sip)
 		SIP_SEND_CSTA_MONITOR_STOP,
 		sip->csta->monitor_cross_ref_id);
 
-	send_sip_request(sip->gc,
-			 "INFO",
-			 sip->csta->dialog->with,
-			 sip->csta->dialog->with,
-			 hdr,
-			 body,
-			 sip->csta->dialog,
-			 NULL);
+	sip_transport_info(sipe_private,
+			   hdr,
+			   body,
+			   sip->csta->dialog,
+			   NULL);
 	g_free(body);
 	g_free(hdr);
 }
 
 static void
-sipe_invite_csta_gateway(struct sipe_account_data *sip);
+sipe_invite_csta_gateway(struct sipe_core_private *sipe_private,
+			 gpointer unused);
 
 /** a callback */
 static gboolean
-process_invite_csta_gateway_response(struct sipe_account_data *sip,
+process_invite_csta_gateway_response(struct sipe_core_private *sipe_private,
 				     struct sipmsg *msg,
 				     SIPE_UNUSED_PARAMETER struct transaction *trans)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
+
 	SIPE_DEBUG_INFO("process_invite_csta_gateway_response:\n%s", msg->body ? msg->body : "");
 
 	if (!sip->csta) {
@@ -370,7 +374,7 @@ process_invite_csta_gateway_response(struct sipe_account_data *sip,
 	if (msg->response >= 200) {
 		/* send ACK to CSTA */
 		sip->csta->dialog->cseq = 0;
-		send_sip_request(sip->gc, "ACK", sip->csta->dialog->with, sip->csta->dialog->with, NULL, NULL, sip->csta->dialog, NULL);
+		sip_transport_ack(sipe_private, sip->csta->dialog);
 		sip->csta->dialog->outgoing_invite = NULL;
 		sip->csta->dialog->is_established = TRUE;
 	}
@@ -389,8 +393,8 @@ process_invite_csta_gateway_response(struct sipe_account_data *sip,
 				sip->csta->gateway_status ? sip->csta->gateway_status : "");
 		if (sipe_strcase_equal(sip->csta->gateway_status, "normal")) {
 			if (!sip->csta->monitor_cross_ref_id) {
-				sip_csta_get_features(sip);
-				sip_csta_monitor_start(sip);
+				sip_csta_get_features(sipe_private);
+				sip_csta_monitor_start(sipe_private);
 			}
 		} else {
 			SIPE_DEBUG_INFO("process_invite_csta_gateway_response: ERROR: CSTA status is %s, won't continue.",
@@ -401,12 +405,12 @@ process_invite_csta_gateway_response(struct sipe_account_data *sip,
 
 		/* schedule re-invite. RFC4028 */
 		if (sip->csta->dialog->expires) {
-			sipe_schedule_action("<+csta>",
-					     sip->csta->dialog->expires - 60, /* 1 minute earlier */
-					     (Action)sipe_invite_csta_gateway,
-					     NULL,
-					     sip,
-					     NULL);
+			sipe_schedule_seconds(sipe_private,
+					      "<+csta>",
+					      NULL,
+					      sip->csta->dialog->expires - 60, /* 1 minute earlier */
+					      sipe_invite_csta_gateway,
+					      NULL);
 		}
 	}
 
@@ -416,8 +420,10 @@ process_invite_csta_gateway_response(struct sipe_account_data *sip,
 /** Creates long living dialog with SIP/CSTA Gateway */
 /*  should be re-entrant as require to sent re-invites every 10 min to refresh */
 static void
-sipe_invite_csta_gateway(struct sipe_account_data *sip)
+sipe_invite_csta_gateway(struct sipe_core_private *sipe_private,
+			 SIPE_UNUSED_PARAMETER gpointer unused)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	gchar *hdr;
 	gchar *contact;
 	gchar *body;
@@ -436,7 +442,7 @@ sipe_invite_csta_gateway(struct sipe_account_data *sip)
 		sip->csta->dialog->ourtag = gentag();
 	}
 
-	contact = get_contact(sip);
+	contact = get_contact(sipe_private);
 	hdr = g_strdup_printf(
 		"Contact: %s\r\n"
 		"Supported: timer\r\n"
@@ -449,25 +455,23 @@ sipe_invite_csta_gateway(struct sipe_account_data *sip)
 		SIP_SEND_CSTA_REQUEST_SYSTEM_STATUS,
 		sip->csta->line_uri);
 
-	sip->csta->dialog->outgoing_invite = send_sip_request(sip->gc,
-							      "INVITE",
-							      sip->csta->dialog->with,
-							      sip->csta->dialog->with,
-							      hdr,
-							      body,
-							      sip->csta->dialog,
-							      process_invite_csta_gateway_response);
+	sip->csta->dialog->outgoing_invite =
+		sip_transport_invite(sipe_private,
+				     hdr,
+				     body,
+				     sip->csta->dialog,
+				     process_invite_csta_gateway_response);
 	g_free(body);
 	g_free(hdr);
 }
 
 void
-sip_csta_open(struct sipe_account_data *sip,
+sip_csta_open(struct sipe_core_private *sipe_private,
 	      const gchar *line_uri,
 	      const gchar *server)
 {
-	sip_csta_initialize(sip, line_uri, server);
-	sipe_invite_csta_gateway(sip);
+	sip_csta_initialize(sipe_private, line_uri, server);
+	sipe_invite_csta_gateway(sipe_private, NULL);
 }
 
 static void
@@ -491,22 +495,16 @@ sip_csta_free(struct sip_csta *csta)
 }
 
 void
-sip_csta_close(struct sipe_account_data *sip)
+sip_csta_close(struct sipe_core_private *sipe_private)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	if (sip->csta) {
-		sip_csta_monitor_stop(sip);
+		sip_csta_monitor_stop(sipe_private);
 	}
 
 	if (sip->csta && sip->csta->dialog) {
 		/* send BYE to CSTA */
-		send_sip_request(sip->gc,
-				 "BYE",
-				 sip->csta->dialog->with,
-				 sip->csta->dialog->with,
-				 NULL,
-				 NULL,
-				 sip->csta->dialog,
-				 NULL);
+		sip_transport_bye(sipe_private, sip->csta->dialog);
 	}
 
 	sip_csta_free(sip->csta);
@@ -516,10 +514,12 @@ sip_csta_close(struct sipe_account_data *sip)
 
 /** Make Call's callback */
 static gboolean
-process_csta_make_call_response(struct sipe_account_data *sip,
+process_csta_make_call_response(struct sipe_core_private *sipe_private,
 				struct sipmsg *msg,
 				SIPE_UNUSED_PARAMETER struct transaction *trans)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
+
 	SIPE_DEBUG_INFO("process_csta_make_call_response:\n%s", msg->body ? msg->body : "");
 
 	if (!sip->csta) {
@@ -556,9 +556,10 @@ process_csta_make_call_response(struct sipe_account_data *sip,
 
 /** Make Call */
 void
-sip_csta_make_call(struct sipe_account_data *sip,
+sip_csta_make_call(struct sipe_core_private *sipe_private,
 		   const gchar* to_tel_uri)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	gchar *hdr;
 	gchar *body;
 
@@ -584,14 +585,11 @@ sip_csta_make_call(struct sipe_account_data *sip,
 		sip->csta->line_uri,
 		sip->csta->to_tel_uri);
 
-	send_sip_request(sip->gc,
-			 "INFO",
-			 sip->csta->dialog->with,
-			 sip->csta->dialog->with,
-			 hdr,
-			 body,
-			 sip->csta->dialog,
-			 process_csta_make_call_response);
+	sip_transport_info(sipe_private,
+			   hdr,
+			   body,
+			   sip->csta->dialog,
+			   process_csta_make_call_response);
 	g_free(body);
 	g_free(hdr);
 }
@@ -641,9 +639,10 @@ sip_csta_update_id_and_status(struct sip_csta *csta,
 }
 
 void
-process_incoming_info_csta(struct sipe_account_data *sip,
+process_incoming_info_csta(struct sipe_core_private *sipe_private,
 			   struct sipmsg *msg)
 {
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
 	gchar *monitor_cross_ref_id;
 	sipe_xml *xml = sipe_xml_parse(msg->body, msg->bodylen);
 
