@@ -3,6 +3,7 @@
  *
  * pidgin-sipe
  *
+ * Copyright (C) 2010 SIPE Project <http://sipe.sourceforge.net/>
  * Copyright (C) 2009 pier11 <pier11@operamail.com>
  *
  *
@@ -31,8 +32,11 @@
 
 #include <glib.h>
 
-#include "sip-sec.h"
+#include "http-conn.h"
 #include "sipe-backend.h"
+#include "sipe-buddy.h"
+#include "sipe-core.h"
+#include "sipe-core-private.h"
 #include "sipe-cal.h"
 #include "sipe-nls.h"
 #include "sipe-utils.h"
@@ -146,6 +150,107 @@ sipe_cal_event_free(struct sipe_cal_event* cal_event)
 	g_free(cal_event);
 }
 
+void
+sipe_cal_events_free(GSList *cal_events)
+{
+	GSList *entry = cal_events;
+
+	if (!cal_events) return;
+
+	while (entry) {
+		struct sipe_cal_event *cal_event = entry->data;
+		sipe_cal_event_free(cal_event);
+		entry = entry->next;
+	}
+
+	g_slist_free(cal_events);
+}
+
+void
+sipe_cal_calendar_free(struct sipe_calendar *cal)
+{
+	g_free(cal->email);
+	g_free(cal->legacy_dn);
+	if (cal->auth) {
+		g_free(cal->auth->domain);
+		g_free(cal->auth->user);
+		g_free(cal->auth->password);
+	}
+	g_free(cal->auth);
+	g_free(cal->as_url);
+	g_free(cal->oof_url);
+	g_free(cal->oab_url);
+	g_free(cal->domino_url);
+	g_free(cal->oof_state);
+	g_free(cal->oof_note);
+	g_free(cal->free_busy);
+	g_free(cal->working_hours_xml_str);
+
+	sipe_cal_events_free(cal->cal_events);
+
+	if (cal->http_conn) {
+		http_conn_free(cal->http_conn);
+	}
+
+	if (cal->http_session) {
+		http_conn_session_free(cal->http_session);
+	}
+
+	g_free(cal);
+}
+
+gboolean
+sipe_cal_calendar_init(struct sipe_core_private *sipe_private,
+		       gboolean *has_url)
+{
+	struct sipe_account_data *sip = SIPE_ACCOUNT_DATA_PRIVATE;
+	if (!sip->cal) {
+		const char *value;
+
+		sip->cal = g_new0(struct sipe_calendar, 1);
+		sip->cal->sipe_private = sipe_private;
+
+		sip->cal->email = g_strdup(sip->email);
+
+		/* user specified a service URL? */
+		value = sipe_backend_setting(SIPE_CORE_PUBLIC, SIPE_SETTING_EMAIL_URL);
+		if (has_url) *has_url = !is_empty(value);
+		if (!is_empty(value)) {
+			sip->cal->as_url  = g_strdup(value);
+			sip->cal->oof_url = g_strdup(value);
+			sip->cal->domino_url  = g_strdup(value);
+		}
+
+		sip->cal->auth = g_new0(HttpConnAuth, 1);
+		sip->cal->auth->use_negotiate = SIPE_CORE_PUBLIC_FLAG_IS(KRB5);
+
+		/* user specified email login? */
+		value = sipe_backend_setting(SIPE_CORE_PUBLIC, SIPE_SETTING_EMAIL_LOGIN);
+		if (!is_empty(value)) {
+
+			/* user specified email login domain? */
+			const char *tmp = strstr(value, "\\");
+			if (tmp) {
+				sip->cal->auth->domain = g_strndup(value, tmp - value);
+				sip->cal->auth->user   = g_strdup(tmp + 1);
+			} else {
+				sip->cal->auth->user   = g_strdup(value);
+			}
+			sip->cal->auth->password = g_strdup(sipe_backend_setting(SIPE_CORE_PUBLIC,
+										 SIPE_SETTING_EMAIL_PASSWORD));
+
+		} else {
+			/* re-use SIPE credentials */
+			sip->cal->auth->domain   = g_strdup(sip->authdomain);
+			sip->cal->auth->user     = g_strdup(sip->authuser);
+			sip->cal->auth->password = g_strdup(sip->password);
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
+
 char *
 sipe_cal_event_describe(struct sipe_cal_event* cal_event)
 {
