@@ -3,6 +3,7 @@
  *
  * pidgin-sipe
  *
+ * Copyright (C) 2010 SIPE Project <http://sipe.sourceforge.net/>
  * Copyright (C) 2009 pier11 <pier11@operamail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,15 +21,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * Interface dependencies:
- *
- * <time.h>
- * <glib.h>
- */
-
 /* Forward declarations */
 struct sipe_buddy;
+struct sipe_core_private;
 struct _sipe_xml;
 
 /* Calendar statuses */
@@ -38,6 +33,11 @@ struct _sipe_xml;
 #define SIPE_CAL_OOF        3
 #define SIPE_CAL_NO_DATA    4
 
+/* Default granularity of FreeBusy data is 15 minutes */
+#define SIPE_FREE_BUSY_GRANULARITY_SEC	(15*60)
+/* FreeBusy stream duration in seconds. Defaults to 4 days */
+#define SIPE_FREE_BUSY_PERIOD_SEC	(4*(24*60*60))
+
 struct sipe_cal_event {
 	time_t start_time;
 	time_t end_time;
@@ -48,9 +48,56 @@ struct sipe_cal_event {
 	int is_meeting;
 };
 
+/** For extracting our Calendar information from
+  * external sources like Exchange, Lotus Domino.
+  */
+struct sipe_calendar {
+	struct sipe_core_private *sipe_private;
+
+	int state;
+	char *email;
+	char *legacy_dn;
+	HttpConnAuth *auth;
+	int auto_disco_method;
+	int is_ews_disabled;
+	int is_domino_disabled;
+	int is_updated;
+
+	char *as_url;
+	char *oof_url;
+	char *oab_url;
+	char *domino_url;
+
+	char *oof_state; /* Enabled, Disabled, Scheduled */
+	char *oof_note;
+	time_t oof_start;
+	time_t oof_end;
+	time_t updated;
+	gboolean published;
+
+	HttpSession *http_session;
+	HttpConn *http_conn;
+
+	time_t fb_start;
+	/* hex form */
+	char *free_busy;
+	char *working_hours_xml_str;
+	GSList *cal_events;
+};
+
 void
 sipe_cal_event_free(struct sipe_cal_event* cal_event);
 
+void
+sipe_cal_events_free(GSList *cal_events);
+
+void
+sipe_cal_calendar_free(struct sipe_calendar *cal);
+
+gboolean
+sipe_cal_calendar_init(struct sipe_core_private *sipe_private,
+		       gboolean *has_url);
+
 /**
  * Returns hash of Calendar Event for comparison.
  *
@@ -84,7 +131,7 @@ sipe_mktime_tz(struct tm *tm,
  * condenced and base64 encoded form
  *
  * Must be g_free()'d after use.
- */ 
+ */
 char *
 sipe_cal_get_freebusy_base64(const char* freebusy_hex);
 
@@ -115,19 +162,19 @@ sipe_cal_get_description(struct sipe_buddy *buddy);
 /**
  * Returns calendar status SIPE_CAL_* at time specified.
  * Returns SIPE_CAL_NO_DATA if no calendar data availible.
- * 
+ *
  * @param since (out)	Returns beginning time of the status.
  */
 int
 sipe_cal_get_status(struct sipe_buddy *buddy,
 		    time_t time_in_question,
 		    time_t *since);
-		   
+
 /**
  * Returns calendar event at time in question.
- * If conflict, takes last event in the following 
+ * If conflict, takes last event in the following
  * priority order: OOF, Busy, Tentative.
- */ 
+ */
 struct sipe_cal_event*
 sipe_cal_get_event(GSList *cal_events,
 		   time_t time_in_question);
