@@ -3,7 +3,7 @@
  *
  * pidgin-sipe
  *
- * Copyright (C) 2009 SIPE Project <http://sipe.sourceforge.net/>
+ * Copyright (C) 2009-10 SIPE Project <http://sipe.sourceforge.net/>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,19 +20,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * Interface dependencies:
- *
- * <glib.h>
- */
-
 /* Forward declarations */
-struct sipe_account_data;
-
-/**
- * Create a new chat
- */
-void sipe_chat_create(struct sipe_account_data *sip, int id, const char *name);
+struct sipe_core_private;
+struct sip_session;
 
 /**
  * Returns purple's chat name for provided chat identification in protocol.
@@ -55,3 +45,25 @@ sipe_chat_get_name(const gchar *proto_chat_id);
  */
 const gchar *
 sipe_chat_find_name(const gchar *chat_name);
+
+/**
+ * 
+ *
+ * @param sipe_private SIPE core private data
+ * @param session SIPE session for chat
+ */
+void
+sipe_process_pending_invite_queue(struct sipe_core_private *sipe_private,
+				  struct sip_session *session);
+
+/**
+ * Invite @who to chat
+ *
+ * @param sipe_private SIPE core private data
+ * @param session SIPE session for chat
+ * @param who URI whom to invite to chat.
+ */
+void
+sipe_invite_to_chat(struct sipe_core_private *sipe_private,
+		    struct sip_session *session,
+		    const gchar *who);
