@@ -32,17 +32,18 @@
 
 #include <glib.h>
 
-#include "conversation.h"
-
 #include "sipe-common.h"
 #include "sipmsg.h"
-#include "sip-sec.h"
+#include "sip-transport.h"
 #include "sipe-backend.h"
 #include "sipe-chat.h"
 #include "sipe-conf.h"
+#include "sipe-core.h"
+#include "sipe-core-private.h"
 #include "sipe-dialog.h"
 #include "sipe-nls.h"
 #include "sipe-session.h"
+#include "sipe-subscriptions.h"
 #include "sipe-utils.h"
 #include "sipe-xml.h"
 #include "sipe.h"
@@ -201,47 +202,29 @@ rand_guid()
  * @param expires not respected if set to negative value (E.g. -1)
  */
 static void
-sipe_subscribe_conference(struct sipe_account_data *sip,
+sipe_subscribe_conference(struct sipe_core_private *sipe_private,
 			  struct sip_session *session,
-			  const int expires)
+			  gboolean expires)
 {
-	gchar *expires_hdr = (expires >= 0) ? g_strdup_printf("Expires: %d\r\n", expires) : g_strdup("");
-	gchar *contact = get_contact(sip);
-	gchar *hdr = g_strdup_printf(
-		"Event: conference\r\n"
-		"%s"
-		"Accept: application/conference-info+xml\r\n"
-		"Supported: com.microsoft.autoextend\r\n"
-		"Supported: ms-benotify\r\n"
-		"Proxy-Require: ms-benotify\r\n"
-		"Supported: ms-piggyback-first-notify\r\n"
-		"Contact: %s\r\n",
-		expires_hdr,
-		contact);
-	g_free(expires_hdr);
-	g_free(contact);
-
-	send_sip_request(sip->gc,
-			 "SUBSCRIBE",
-			 session->focus_uri,
-			 session->focus_uri,
-			 hdr,
-			 "",
-			 NULL,
-			 process_subscribe_response);
-	g_free(hdr);
+	sipe_subscribe(sipe_private,
+		       session->focus_uri,
+		       "conference",
+		       "application/conference-info+xml",
+		       expires ? "Expires: 0\r\n" : NULL,
+		       NULL,
+		       NULL);
 }
 
 /** Invite us to the focus callback */
 static gboolean
-process_invite_conf_focus_response(struct sipe_account_data *sip,
+process_invite_conf_focus_response(struct sipe_core_private *sipe_private,
 				   struct sipmsg *msg,
 				   SIPE_UNUSED_PARAMETER struct transaction *trans)
 {
 	struct sip_session *session = NULL;
 	char *focus_uri = parse_from(sipmsg_find_header(msg, "To"));
 
-	session = sipe_session_find_conference(sip, focus_uri);
+	session = sipe_session_find_conference(sipe_private, focus_uri);
 
 	if (!session) {
 		SIPE_DEBUG_INFO("process_invite_conf_focus_response: unable to find conf session with focus=%s", focus_uri);
@@ -260,7 +243,7 @@ process_invite_conf_focus_response(struct sipe_account_data *sip,
 	if (msg->response >= 200) {
 		/* send ACK to focus */
 		session->focus_dialog->cseq = 0;
-		send_sip_request(sip->gc, "ACK", session->focus_dialog->with, session->focus_dialog->with, NULL, NULL, session->focus_dialog, NULL);
+		sip_transport_ack(sipe_private, session->focus_dialog);
 		session->focus_dialog->outgoing_invite = NULL;
 		session->focus_dialog->is_established = TRUE;
 	}
@@ -268,7 +251,7 @@ process_invite_conf_focus_response(struct sipe_account_data *sip,
 	if (msg->response >= 400) {
 		SIPE_DEBUG_INFO_NOFORMAT("process_invite_conf_focus_response: INVITE response is not 200. Failed to join focus.");
 		/* @TODO notify user of failure to join focus */
-		sipe_session_remove(sip, session);
+		sipe_session_remove(sipe_private, session);
 		g_free(focus_uri);
 		return FALSE;
 	} else if (msg->response == 200) {
@@ -276,7 +259,7 @@ process_invite_conf_focus_response(struct sipe_account_data *sip,
 		const gchar *code = sipe_xml_attribute(xn_response, "code");
 		if (sipe_strequal(code, "success")) {
 			/* subscribe to focus */
-			sipe_subscribe_conference(sip, session, -1);
+			sipe_subscribe_conference(sipe_private, session, FALSE);
 		}
 		sipe_xml_free(xn_response);
 	}
@@ -287,7 +270,7 @@ process_invite_conf_focus_response(struct sipe_account_data *sip,
 
 /** Invite us to the focus */
 void
-sipe_invite_conf_focus(struct sipe_account_data *sip,
+sipe_invite_conf_focus(struct sipe_core_private *sipe_private,
 		       struct sip_session *session)
 {
 	gchar *hdr;
@@ -310,7 +293,7 @@ sipe_invite_conf_focus(struct sipe_account_data *sip,
 		session->focus_dialog->ourtag = gentag();
 	}
 
-	contact = get_contact(sip);
+	contact = get_contact(sipe_private);
 	hdr = g_strdup_printf(
 		"Supported: ms-sender\r\n"
 		"Contact: %s\r\n"
@@ -320,7 +303,7 @@ sipe_invite_conf_focus(struct sipe_account_data *sip,
 
 	/* @TODO put request_id to queue to further compare with incoming one */
 	/* focus_URI, from, request_id, focus_URI, from, endpoint_GUID */
-	self = sip_uri_self(sip);
+	self = sip_uri_self(sipe_private);
 	body = g_strdup_printf(
 		SIPE_SEND_CONF_ADD_USER,
 		session->focus_dialog->with,
@@ -331,21 +314,19 @@ sipe_invite_conf_focus(struct sipe_account_data *sip,
 		session->focus_dialog->endpoint_GUID);
 	g_free(self);
 
-	session->focus_dialog->outgoing_invite = send_sip_request(sip->gc,
-								  "INVITE",
-								  session->focus_dialog->with,
-								  session->focus_dialog->with,
-								  hdr,
-								  body,
-								  session->focus_dialog,
-								  process_invite_conf_focus_response);
+	session->focus_dialog->outgoing_invite =
+		sip_transport_invite(sipe_private,
+				     hdr,
+				     body,
+				     session->focus_dialog,
+				     process_invite_conf_focus_response);
 	g_free(body);
 	g_free(hdr);
 }
 
 /** Modify User Role */
 void
-sipe_conf_modify_user_role(struct sipe_account_data *sip,
+sipe_conf_modify_user_role(struct sipe_core_private *sipe_private,
 			   struct sip_session *session,
 			   const gchar* who)
 {
@@ -362,7 +343,7 @@ sipe_conf_modify_user_role(struct sipe_account_data *sip,
 		"Content-Type: application/cccp+xml\r\n");
 
 	/* @TODO put request_id to queue to further compare with incoming one */
-	self = sip_uri_self(sip);
+	self = sip_uri_self(sipe_private);
 	body = g_strdup_printf(
 		SIPE_SEND_CONF_MODIFY_USER_ROLES,
 		session->focus_dialog->with,
@@ -372,21 +353,18 @@ sipe_conf_modify_user_role(struct sipe_account_data *sip,
 		who);
 	g_free(self);
 
-	send_sip_request(sip->gc,
-			 "INFO",
-			 session->focus_dialog->with,
-			 session->focus_dialog->with,
-			 hdr,
-			 body,
-			 session->focus_dialog,
-			 NULL);
+	sip_transport_info(sipe_private,
+			   hdr,
+			   body,
+			   session->focus_dialog,
+			   NULL);
 	g_free(body);
 	g_free(hdr);
 }
 
 /** Modify Conference Lock */
 void
-sipe_conf_modify_conference_lock(struct sipe_account_data *sip,
+sipe_conf_modify_conference_lock(struct sipe_core_private *sipe_private,
 				 struct sip_session *session,
 				 const gboolean locked)
 {
@@ -403,7 +381,7 @@ sipe_conf_modify_conference_lock(struct sipe_account_data *sip,
 		"Content-Type: application/cccp+xml\r\n");
 
 	/* @TODO put request_id to queue to further compare with incoming one */
-	self = sip_uri_self(sip);
+	self = sip_uri_self(sipe_private);
 	body = g_strdup_printf(
 		SIPE_SEND_CONF_MODIFY_CONF_LOCK,
 		session->focus_dialog->with,
@@ -413,21 +391,18 @@ sipe_conf_modify_conference_lock(struct sipe_account_data *sip,
 		locked ? "true" : "false");
 	g_free(self);
 
-	send_sip_request(sip->gc,
-			 "INFO",
-			 session->focus_dialog->with,
-			 session->focus_dialog->with,
-			 hdr,
-			 body,
-			 session->focus_dialog,
-			 NULL);
+	sip_transport_info(sipe_private,
+			   hdr,
+			   body,
+			   session->focus_dialog,
+			   NULL);
 	g_free(body);
 	g_free(hdr);
 }
 
 /** Modify Delete User */
 void
-sipe_conf_delete_user(struct sipe_account_data *sip,
+sipe_conf_delete_user(struct sipe_core_private *sipe_private,
 		      struct sip_session *session,
 		      const gchar* who)
 {
@@ -444,7 +419,7 @@ sipe_conf_delete_user(struct sipe_account_data *sip,
 		"Content-Type: application/cccp+xml\r\n");
 
 	/* @TODO put request_id to queue to further compare with incoming one */
-	self = sip_uri_self(sip);
+	self = sip_uri_self(sipe_private);
 	body = g_strdup_printf(
 		SIPE_SEND_CONF_DELETE_USER,
 		session->focus_dialog->with,
@@ -454,21 +429,18 @@ sipe_conf_delete_user(struct sipe_account_data *sip,
 		who);
 	g_free(self);
 
-	send_sip_request(sip->gc,
-			 "INFO",
-			 session->focus_dialog->with,
-			 session->focus_dialog->with,
-			 hdr,
-			 body,
-			 session->focus_dialog,
-			 NULL);
+	sip_transport_info(sipe_private,
+			   hdr,
+			   body,
+			   session->focus_dialog,
+			   NULL);
 	g_free(body);
 	g_free(hdr);
 }
 
 /** Invite counterparty to join conference callback */
 static gboolean
-process_invite_conf_response(struct sipe_account_data *sip,
+process_invite_conf_response(struct sipe_core_private *sipe_private,
 			     struct sipmsg *msg,
 			     SIPE_UNUSED_PARAMETER struct transaction *trans)
 {
@@ -482,7 +454,7 @@ process_invite_conf_response(struct sipe_account_data *sip,
 	if (msg->response >= 200) {
 		/* send ACK to counterparty */
 		dialog->cseq--;
-		send_sip_request(sip->gc, "ACK", dialog->with, dialog->with, NULL, NULL, dialog, NULL);
+		sip_transport_ack(sipe_private, dialog);
 		dialog->outgoing_invite = NULL;
 		dialog->is_established = TRUE;
 	}
@@ -495,12 +467,12 @@ process_invite_conf_response(struct sipe_account_data *sip,
 	}
 
 	if (msg->response >= 200) {
-		struct sip_session *session = sipe_session_find_im(sip, dialog->with);
+		struct sip_session *session = sipe_session_find_im(sipe_private, dialog->with);
 		struct sip_dialog *im_dialog = sipe_dialog_find(session, dialog->with);
 
 		/* close IM session to counterparty */
 		if (im_dialog) {
-			send_sip_request(sip->gc, "BYE", im_dialog->with, im_dialog->with, NULL, NULL, im_dialog, NULL);
+			sip_transport_bye(sipe_private, im_dialog);
 			sipe_dialog_remove(session, dialog->with);
 		}
 	}
@@ -513,7 +485,7 @@ process_invite_conf_response(struct sipe_account_data *sip,
  * Invites counterparty to join conference.
  */
 void
-sipe_invite_conf(struct sipe_account_data *sip,
+sipe_invite_conf(struct sipe_core_private *sipe_private,
 		 struct sip_session *session,
 		 const gchar* who)
 {
@@ -530,7 +502,7 @@ sipe_invite_conf(struct sipe_account_data *sip,
 	dialog->with = g_strdup(who);
 	dialog->ourtag = gentag();
 
-	contact = get_contact(sip);
+	contact = get_contact(sipe_private);
 	hdr = g_strdup_printf(
 		"Supported: ms-sender\r\n"
 		"Contact: %s\r\n"
@@ -544,14 +516,11 @@ sipe_invite_conf(struct sipe_account_data *sip,
 		session->subject ? session->subject : ""
 		);
 
-	send_sip_request( sip->gc,
-			  "INVITE",
-			  dialog->with,
-			  dialog->with,
-			  hdr,
-			  body,
-			  dialog,
-			  process_invite_conf_response);
+	sip_transport_invite(sipe_private,
+			     hdr,
+			     body,
+			     dialog,
+			     process_invite_conf_response);
 
 	sipe_dialog_free(dialog);
 	g_free(body);
@@ -560,7 +529,7 @@ sipe_invite_conf(struct sipe_account_data *sip,
 
 /** Create conference callback */
 static gboolean
-process_conf_add_response(struct sipe_account_data *sip,
+process_conf_add_response(struct sipe_core_private *sipe_private,
 			  struct sipmsg *msg,
 			  struct transaction *trans)
 {
@@ -577,7 +546,7 @@ process_conf_add_response(struct sipe_account_data *sip,
 			struct sip_session *session;
 			const sipe_xml *xn_conference_info = sipe_xml_child(xn_response, "addConference/conference-info");
 
-			session = sipe_session_add_chat(sip);
+			session = sipe_session_add_chat(sipe_private);
 			session->is_multiparty = FALSE;
 			session->focus_uri = g_strdup(sipe_xml_attribute(xn_conference_info, "entity"));
 			SIPE_DEBUG_INFO("process_conf_add_response: session->focus_uri=%s",
@@ -587,7 +556,7 @@ process_conf_add_response(struct sipe_account_data *sip,
 				session->pending_invite_queue, g_strdup(who), (GCompareFunc)strcmp);
 
 			/* add self to conf */
-			sipe_invite_conf_focus(sip, session);
+			sipe_invite_conf_focus(sipe_private, session);
 		}
 		sipe_xml_free(xn_response);
 	}
@@ -599,7 +568,7 @@ process_conf_add_response(struct sipe_account_data *sip,
  * Creates conference.
  */
 void
-sipe_conf_add(struct sipe_account_data *sip,
+sipe_conf_add(struct sipe_core_private *sipe_private,
 	      const gchar* who)
 {
 	gchar *hdr;
@@ -613,7 +582,7 @@ sipe_conf_add(struct sipe_account_data *sip,
 	char *expiry_time;
 	struct transaction_payload *payload;
 
-	contact = get_contact(sip);
+	contact = get_contact(sipe_private);
 	hdr = g_strdup_printf(
 		"Supported: ms-sender\r\n"
 		"Contact: %s\r\n"
@@ -622,11 +591,11 @@ sipe_conf_add(struct sipe_account_data *sip,
 	g_free(contact);
 
 	expiry_time = sipe_utils_time_to_str(expiry);
-	self = sip_uri_self(sip);
+	self = sip_uri_self(sipe_private);
 	conference_id = genconfid();
 	body = g_strdup_printf(
 		SIPE_SEND_CONF_ADD,
-		sip->focus_factory_uri,
+		sipe_private->focus_factory_uri,
 		self,
 		rand(),
 		conference_id,
@@ -635,14 +604,11 @@ sipe_conf_add(struct sipe_account_data *sip,
 	g_free(conference_id);
 	g_free(expiry_time);
 
-	trans = send_sip_request( sip->gc,
-				  "SERVICE",
-				  sip->focus_factory_uri,
-				  sip->focus_factory_uri,
-				  hdr,
-				  body,
-				  NULL,
-				  process_conf_add_response);
+	trans = sip_transport_service(sipe_private,
+				      sipe_private->focus_factory_uri,
+				      hdr,
+				      body,
+				      process_conf_add_response);
 
 	payload = g_new0(struct transaction_payload, 1);
 	payload->destroy = g_free;
@@ -655,7 +621,7 @@ sipe_conf_add(struct sipe_account_data *sip,
 }
 
 void
-process_incoming_invite_conf(struct sipe_account_data *sip,
+process_incoming_invite_conf(struct sipe_core_private *sipe_private,
 			     struct sipmsg *msg)
 {
 	struct sip_session *session = NULL;
@@ -685,22 +651,22 @@ process_incoming_invite_conf(struct sipe_account_data *sip,
 	dialog->with = parse_from(sipmsg_find_header(msg, "From"));
 	sipe_dialog_parse(dialog, msg, FALSE);
 
-	send_sip_response(sip->gc, msg, 200, "OK", NULL);
+	sip_transport_response(sipe_private, msg, 200, "OK", NULL);
 
-	session = sipe_session_add_chat(sip);
+	session = sipe_session_add_chat(sipe_private);
 	session->focus_uri = focus_uri;
 	session->is_multiparty = FALSE;
 
 	/* send BYE to invitor */
-	send_sip_request(sip->gc, "BYE", dialog->with, dialog->with, NULL, NULL, dialog, NULL);
+	sip_transport_bye(sipe_private, dialog);
 	sipe_dialog_free(dialog);
 
 	/* add self to conf */
-	sipe_invite_conf_focus(sip, session);
+	sipe_invite_conf_focus(sipe_private, session);
 }
 
 void
-sipe_process_conference(struct sipe_account_data *sip,
+sipe_process_conference(struct sipe_core_private *sipe_private,
 			struct sipmsg *msg)
 {
 	sipe_xml *xn_conference_info;
@@ -718,32 +684,24 @@ sipe_process_conference(struct sipe_account_data *sip,
 	if (!xn_conference_info) return;
 
 	focus_uri = sipe_xml_attribute(xn_conference_info, "entity");
-	session = sipe_session_find_conference(sip, focus_uri);
+	session = sipe_session_find_conference(sipe_private, focus_uri);
 
 	if (!session) {
 		SIPE_DEBUG_INFO("sipe_process_conference: unable to find conf session with focus=%s", focus_uri);
 		return;
 	}
 
-	if (session->focus_uri && !session->conv) {
+	if (session->focus_uri && !session->backend_session) {
 		gchar *chat_title = sipe_chat_get_name(session->focus_uri);
-		gchar *self = sip_uri_self(sip);
-		/* can't be find by chat id as it won't survive acc reinstantation */
-		PurpleConversation *conv = NULL;
+		gchar *self = sip_uri_self(sipe_private);
 
-		if (chat_title) {
-			conv = purple_find_conversation_with_account(PURPLE_CONV_TYPE_CHAT,
-								     chat_title,
-								     sip->account);
-		}
-		/* to be able to rejoin existing chat/window */
-		if (conv && !purple_conv_chat_has_left(PURPLE_CONV_CHAT(conv))) {
-			PURPLE_CONV_CHAT(conv)->left = TRUE;
-		}
-		/* create prpl chat */
-		session->conv = serv_got_joined_chat(sip->gc, session->chat_id, chat_title);
+		/* create or join existing chat */
+		session->backend_session = sipe_backend_chat_create(SIPE_CORE_PUBLIC,
+								    session->chat_id,
+								    chat_title,
+								    self,
+								    TRUE);
 		session->chat_title = chat_title;
-		purple_conv_chat_set_nick(PURPLE_CONV_CHAT(session->conv), self);
 		just_joined = TRUE;
 		/* @TODO ask for full state (re-subscribe) if it was a partial one -
 		 * this is to obtain full list of conference participants.
@@ -755,7 +713,7 @@ sipe_process_conference(struct sipe_account_data *sip,
 	if ((xn_subject = sipe_xml_child(xn_conference_info, "conference-description/subject"))) {
 		g_free(session->subject);
 		session->subject = sipe_xml_data(xn_subject);
-		purple_conv_chat_set_topic(PURPLE_CONV_CHAT(session->conv), NULL, session->subject);
+		sipe_backend_chat_topic(session->backend_session, session->subject);
 		SIPE_DEBUG_INFO("sipe_process_conference: subject=%s", session->subject ? session->subject : "");
 	}
 
@@ -781,19 +739,15 @@ sipe_process_conference(struct sipe_account_data *sip,
 	for (node = sipe_xml_child(xn_conference_info, "users/user"); node; node = sipe_xml_twin(node)) {
 		const gchar *user_uri = sipe_xml_attribute(node, "entity");
 		const gchar *state = sipe_xml_attribute(node, "state");
-		gchar *role  = sipe_xml_data(sipe_xml_child(node, "roles/entry"));
-		PurpleConvChatBuddyFlags flags = PURPLE_CBFLAGS_NONE;
-		PurpleConvChat *chat = PURPLE_CONV_CHAT(session->conv);
+		gchar *role = sipe_xml_data(sipe_xml_child(node, "roles/entry"));
+		gboolean is_operator = sipe_strequal(role, "presenter");
 		gboolean is_in_im_mcu = FALSE;
-		gchar *self = sip_uri_self(sip);
-
-		if (sipe_strequal(role, "presenter")) {
-			flags |= PURPLE_CBFLAGS_OP;
-		}
+		gchar *self = sip_uri_self(sipe_private);
 
 		if (sipe_strequal("deleted", state)) {
-			if (purple_conv_chat_find_user(chat, user_uri)) {
-				purple_conv_chat_remove_user(chat, user_uri, NULL /* reason */);
+			if (sipe_backend_chat_find(session->backend_session, user_uri)) {
+				sipe_backend_chat_remove(session->backend_session,
+							 user_uri);
 			}
 		} else {
 			/* endpoints */
@@ -803,11 +757,14 @@ sipe_process_conference(struct sipe_account_data *sip,
 					gchar *status = sipe_xml_data(sipe_xml_child(endpoint, "status"));
 					if (sipe_strequal("connected", status)) {
 						is_in_im_mcu = TRUE;
-						if (!purple_conv_chat_find_user(chat, user_uri)) {
-							purple_conv_chat_add_user(chat, user_uri, NULL, flags,
-										  !just_joined && g_strcasecmp(user_uri, self));
-						} else {
-							purple_conv_chat_user_set_flags(chat, user_uri, flags);
+						if (!sipe_backend_chat_find(session->backend_session, user_uri)) {
+							sipe_backend_chat_add(session->backend_session,
+									      user_uri,
+									      !just_joined && g_strcasecmp(user_uri, self));
+						}
+						if (is_operator) {
+							sipe_backend_chat_operator(session->backend_session,
+										   user_uri);
 						}
 					}
 					g_free(status);
@@ -815,8 +772,9 @@ sipe_process_conference(struct sipe_account_data *sip,
 				}
 			}
 			if (!is_in_im_mcu) {
-				if (purple_conv_chat_find_user(chat, user_uri)) {
-					purple_conv_chat_remove_user(chat, user_uri, NULL /* reason */);
+				if (sipe_backend_chat_find(session->backend_session, user_uri)) {
+					sipe_backend_chat_remove(session->backend_session,
+								 user_uri);
 				}
 			}
 		}
@@ -838,11 +796,11 @@ sipe_process_conference(struct sipe_account_data *sip,
 				gboolean prev_locked = session->locked;
 				session->locked = sipe_strequal(locked, "true");
 				if (prev_locked && !session->locked) {
-					sipe_present_info(sip, session,
+					sipe_present_info(sipe_private, session,
 						_("This conference is no longer locked. Additional participants can now join."));
 				}
 				if (!prev_locked && session->locked) {
-					sipe_present_info(sip, session,
+					sipe_present_info(sipe_private, session,
 						_("This conference is locked. Nobody else can join the conference while it is locked."));
 				}
 
@@ -864,62 +822,52 @@ sipe_process_conference(struct sipe_account_data *sip,
 			dialog->with = g_strdup(session->im_mcu_uri);
 
 			/* send INVITE to IM MCU */
-			sipe_invite(sip, session, dialog->with, NULL, NULL, NULL, FALSE);
+			sipe_invite(sipe_private, session, dialog->with, NULL, NULL, NULL, FALSE);
 		}
 	}
 
-	sipe_process_pending_invite_queue(sip, session);
+	sipe_process_pending_invite_queue(sipe_private, session);
 }
 
 void
-sipe_conf_immcu_closed(struct sipe_account_data *sip,
+sipe_conf_immcu_closed(struct sipe_core_private *sipe_private,
 		       struct sip_session *session)
 {
-	sipe_present_info(sip, session,
+	sipe_present_info(sipe_private, session,
 			  _("You have been disconnected from this conference."));
-	purple_conv_chat_clear_users(PURPLE_CONV_CHAT(session->conv));
+	sipe_backend_chat_close(session->backend_session);
 }
 
 void
-conf_session_close(struct sipe_account_data *sip,
+conf_session_close(struct sipe_core_private *sipe_private,
 		   struct sip_session *session)
 {
 	if (session) {
 		/* unsubscribe from focus */
-		sipe_subscribe_conference(sip, session, 0);
+		sipe_subscribe_conference(sipe_private, session, TRUE);
 
 		if (session->focus_dialog) {
 			/* send BYE to focus */
-			send_sip_request(sip->gc,
-					 "BYE",
-					 session->focus_dialog->with,
-					 session->focus_dialog->with,
-					 NULL,
-					 NULL,
-					 session->focus_dialog,
-					 NULL);
+			sip_transport_bye(sipe_private, session->focus_dialog);
 		}
 	}
 }
 
 void
-sipe_process_imdn(struct sipe_account_data *sip,
+sipe_process_imdn(struct sipe_core_private *sipe_private,
 		  struct sipmsg *msg)
 {
 	gchar *with = parse_from(sipmsg_find_header(msg, "From"));
-	const gchar *call_id = sipmsg_find_header(msg, "Call-ID");
+	const gchar *callid = sipmsg_find_header(msg, "Call-ID");
 	static struct sip_session *session;
 	sipe_xml *xn_imdn;
 	const sipe_xml *node;
 	gchar *message_id;
 	gchar *message;
 
-	session = sipe_session_find_chat_by_callid(sip, call_id);
+	session = sipe_session_find_chat_or_im(sipe_private, callid, with);
 	if (!session) {
-		session = sipe_session_find_im(sip, with);
-	}
-	if (!session) {
-		SIPE_DEBUG_INFO("sipe_process_imdn: unable to find conf session with call_id=%s", call_id);
+		SIPE_DEBUG_INFO("sipe_process_imdn: unable to find conf session with callid=%s", callid);
 		g_free(with);
 		return;
 	}
@@ -933,7 +881,7 @@ sipe_process_imdn(struct sipe_account_data *sip,
 	for (node = sipe_xml_child(xn_imdn, "recipient"); node; node = sipe_xml_twin(node)) {
 		gchar *tmp = parse_from(sipe_xml_attribute(node, "uri"));
 		gchar *uri = parse_from(tmp);
-		sipe_present_message_undelivered_err(sip, session, -1, -1, uri, message);
+		sipe_present_message_undelivered_err(sipe_private, session, -1, -1, uri, message);
 		g_free(tmp);
 		g_free(uri);
 	}
