@@ -28,109 +28,14 @@
  *
  * <time.h>
  * <glib.h>
- * "sip-sec.h"
  */
 
 /* Forward declarations */
 struct sipmsg;
 struct _PurpleAccount;
-struct _PurpleCircBuffer;
 struct _PurpleConnection;
-struct _PurpleDnsQueryData;
 struct _PurpleGroup;
-struct _PurpleNetworkListenData;
-struct _PurplePlugin;
-struct _PurpleSrvQueryData;
-struct _PurpleSslConnection;
-struct sip_sec_context;
-enum sip_sec_auth_type;
-
-#define SIMPLE_BUF_INC 4096
-
-#define SIPE_TYPING_RECV_TIMEOUT 6
-#define SIPE_TYPING_SEND_TIMEOUT 4
-
-
-/** Activity (token and description) 2007 */
-typedef enum
-{
-	SIPE_ACTIVITY_UNSET = 0,
-	SIPE_ACTIVITY_ONLINE,
-	SIPE_ACTIVITY_INACTIVE,
-	SIPE_ACTIVITY_BUSY,
-	SIPE_ACTIVITY_BUSYIDLE,
-	SIPE_ACTIVITY_DND,
-	SIPE_ACTIVITY_BRB,
-	SIPE_ACTIVITY_AWAY,
-	SIPE_ACTIVITY_LUNCH,
-	SIPE_ACTIVITY_OFFLINE,
-	SIPE_ACTIVITY_ON_PHONE,
-	SIPE_ACTIVITY_IN_CONF,
-	SIPE_ACTIVITY_IN_MEETING,
-	SIPE_ACTIVITY_OOF,
-	SIPE_ACTIVITY_URGENT_ONLY,
-	SIPE_ACTIVITY_NUM_TYPES
-} sipe_activity;
-
-struct sipe_buddy {
-	gchar *name;
-	gchar *activity;
-	gchar *meeting_subject;
-	gchar *meeting_location;
-	/* Sipe internal format for Note is HTML.
-	 * All incoming plain text should be html-escaped
-	 * for example by g_markup_escape_text()
-	 */
-	gchar *note;
-	gboolean is_oof_note;
-	time_t note_since;
-
-	/* Calendar related fields */
-	gchar *cal_start_time;
-	int cal_granularity;
-	gchar *cal_free_busy_base64;
-	gchar *cal_free_busy;
-	time_t cal_free_busy_published;
-	/* for 2005 systems */
-	int user_avail;
-	time_t user_avail_since;
-	time_t activity_since;
-	const char *last_non_cal_status_id;
-	gchar *last_non_cal_activity;
-
-	struct sipe_cal_working_hours *cal_working_hours;
-
-	gchar *device_name;
-	GSList *groups;
-	 /** flag to control sending 'context' element in 2007 subscriptions */
-	gboolean just_added;
-};
-
-struct sip_auth {
-	enum sip_sec_auth_type type;
-	struct sip_sec_context *gssapi_context;
-	gchar *gssapi_data;
-	gchar *opaque;
-	gchar *realm;
-	gchar *target;
-	int version;
-	int nc;
-	int retries;
-	int ntlm_num;
-	int expires;
-};
-
-typedef enum {
-	SIPE_TRANSPORT_TLS,
-	SIPE_TRANSPORT_TCP,
-	SIPE_TRANSPORT_UDP,
-} sipe_transport_type;
-
-struct sipe_service_data {
-	const char *service;
-	const char *transport;
-	sipe_transport_type type;
-};
+struct sipe_core_private;
 
 /** MS-PRES publication */
 struct sipe_publication {
@@ -150,54 +55,20 @@ struct sipe_publication {
 	char *free_busy_base64;
 };
 
-/** MS-PRES container */
-struct sipe_container {
-	guint id;
-	guint version;
-	GSList *members;
-};
-/** MS-PRES container member */
-struct sipe_container_member {
-	/** user, domain, sameEnterprise, federated, publicCloud; everyone */
-	gchar *type;
-	gchar *value;
-};
-
 struct sipe_account_data {
 	struct _PurpleConnection *gc;
-	gchar *sipdomain;
-	gchar *username;
 	gchar *authdomain;
 	gchar *authuser;
 	gchar *password;
-	gchar *epid;
-	gchar *focus_factory_uri;
 	/** Allowed server events to subscribe. From register OK response. */
 	GSList *allow_events;
-	struct _PurpleDnsQueryData *query_data;
-	struct _PurpleSrvQueryData *srv_query_data;
-	const struct sipe_service_data *service_data;
-	struct _PurpleNetworkListenData *listen_data;
-	int fd;
-	int cseq;
-	time_t last_keepalive;
-	int registerstatus; /* 0 nothing, 1 first registration send, 2 auth received, 3 registered */
-	struct sip_auth registrar;
-	struct sip_auth proxy;
 	struct sip_csta *csta; /* For RCC - Remote Call Control */
-	gboolean reregister_set; /* whether reregister timer set */
-	gboolean reauthenticate_set; /* whether reauthenticate timer set */
-	gboolean subscribed; /* whether subscribed to events, except buddies presence */
 	gboolean subscribed_buddies; /* whether subscribed to buddies presence */
 	gboolean access_level_set; /* whether basic access level set */
 	gboolean initial_state_published; /* whether we published our initial state */
 	GSList *our_publication_keys;		/* [MS-PRES] */
 	GHashTable *our_publications;		/* [MS-PRES] */
 	GHashTable *user_state_publications;	/* [MS-PRES] */
-	GHashTable *subscriptions;
-	int listenfd;
-	int listenport;
-	int listenpa;
 	int contacts_delta;
 	int acl_delta;
 	int presence_method_version;
@@ -207,33 +78,12 @@ struct sipe_account_data {
 	gchar *note;
 	time_t note_since;
 	time_t idle_switch;
-	gchar *contact;
-	gchar *server_version;
-	gboolean ocs2007; /*if there is support for batched category subscription [SIP-PRES]*/
 	gboolean batched_support; /*if there is support for batched subscription*/
 	GSList *containers; /* MS-PRES containers */
-	GHashTable *buddies;
-	guint resendtimeout;
-	guint keepalive_timeout;
-	GSList *timeouts;
-	gboolean connecting;
 	struct _PurpleAccount *account;
-	struct _PurpleCircBuffer *txbuf;
-	guint tx_handler;
 	gchar *regcallid;
-	GSList *transactions;
-	GSList *sessions;
-	GSList *openconns;
 	GSList *groups;
-	GHashTable *filetransfers;
-	sipe_transport_type transport;
-	gboolean auto_transport;
-	struct _PurpleSslConnection *gsc;
-	struct sockaddr *serveraddr;
-	gchar *realhostname;
-	int realport; /* port and hostname from SRV record */
-	gboolean processing_input;
-	struct sipe_ews *ews;
+	struct sipe_calendar *cal;
 	gchar *email;
 	/** 2005 Custom XML piece.
 	 * Possibly set by other point of presence or just other client at earlier time.
@@ -247,64 +97,11 @@ struct sipe_account_data {
 	gchar *user_states;
 };
 
-struct sip_connection {
-	int fd;
-	gchar *inbuf;
-	int inbuflen;
-	int inbufused;
-	int inputhandler;
-};
-
 struct sipe_auth_job {
-	gchar * who;
-	struct sipe_account_data * sip;
+	gchar *who;
+	struct sipe_core_private *sipe_private;
 };
 
-struct transaction;
-
-typedef gboolean (*TransCallback) (struct sipe_account_data *, struct sipmsg *, struct transaction *);
-
-struct transaction_payload {
-	GDestroyNotify destroy;
-	void *data;
-};
-
-struct transaction {
-	time_t time;
-	int retries;
-	int transport; /* 0 = tcp, 1 = udp */
-	int fd;
-	/** Not yet perfect, but surely better then plain CSeq
-	 * Format is: <Call-ID><CSeq>
-	 * (RFC3261 17.2.3 for matching server transactions: Request-URI, To tag, From tag, Call-ID, CSeq, and top Via)
-	 */
-	gchar *key;
-	struct sipmsg *msg;
-	TransCallback callback;
-	struct transaction_payload *payload;
-};
-
-typedef void (*Action) (struct sipe_account_data *, void *);
-
-/**
-  * Do schedule action for execution in the future.
-  * Non repetitive execution.
-  *
-  * @param   name of action (will be copied)
-  * @param   timeout in seconds
-  * @param   action  callback function
-  * @param   destroy payload destroy function
-  * @param   sip
-  * @param   payload callback data (can be NULL, otherwise caller must allocate memory)
-  */
-void
-sipe_schedule_action(const gchar *name,
-		     int timeout,
-		     Action action,
-		     GDestroyNotify destroy,
-		     struct sipe_account_data *sip,
-		     void *payload);
-
 struct sipe_group {
 	gchar *name;
 	int id;
@@ -327,13 +124,14 @@ GSList * slist_insert_unique_sorted(GSList *list, gpointer data, GCompareFunc fu
  * For 2007+
  */
 void
-publish_calendar_status_self(struct sipe_account_data *sip);
+publish_calendar_status_self(struct sipe_core_private *sipe_private,
+			     void *unused);
 
 /**
  * For 2005-
  */
 void
-send_presence_soap(struct sipe_account_data *sip,
+send_presence_soap(struct sipe_core_private *sipe_private,
 		   gboolean do_publish_calendar);
 
 /**
@@ -357,31 +155,18 @@ send_presence_soap(struct sipe_account_data *sip,
 /* Forward declarations */
 struct sip_session;
 struct sip_dialog;
+struct transaction;
 
-/* SIP send module? */
-struct transaction *
-send_sip_request(struct _PurpleConnection *gc, const gchar *method,
-		 const gchar *url, const gchar *to, const gchar *addheaders,
-		 const gchar *body, struct sip_dialog *dialog, TransCallback tc);
 void
-send_sip_response(struct _PurpleConnection *gc, struct sipmsg *msg, int code,
-		  const char *text, const char *body);
-void
-sipe_invite(struct sipe_account_data *sip, struct sip_session *session,
+sipe_invite(struct sipe_core_private *sipe_private, struct sip_session *session,
 	    const gchar *who, const gchar *msg_body, const gchar *msg_content_type,
 	    const gchar *referred_by, const gboolean is_triggered);
 /* ??? module */
-gboolean process_subscribe_response(struct sipe_account_data *sip,
-				    struct sipmsg *msg,
-				    struct transaction *tc);
-/* Chat module */
-void
-sipe_invite_to_chat(struct sipe_account_data *sip,
-		    struct sip_session *session,
-		    const gchar *who);
+void sipe_connection_cleanup(struct sipe_core_private *sipe_private);
+void sipe_buddy_free_all(struct sipe_core_private *sipe_private);
 /* Session module? */
 void
-sipe_present_message_undelivered_err(struct sipe_account_data *sip,
+sipe_present_message_undelivered_err(struct sipe_core_private *sipe_private,
 				     struct sip_session *session,
 				     int sip_error,
 				     int sip_warning,
@@ -389,28 +174,36 @@ sipe_present_message_undelivered_err(struct sipe_account_data *sip,
 				     const gchar *message);
 
 void
-sipe_present_info(struct sipe_account_data *sip,
+sipe_present_info(struct sipe_core_private *sipe_private,
+		  struct sip_session *session,
+		  const gchar *message);
+void
+sipe_present_err(struct sipe_core_private *sipe_private,
 		 struct sip_session *session,
 		 const gchar *message);
 
-
 void
-sipe_process_pending_invite_queue(struct sipe_account_data *sip,
-				  struct sip_session *session);
-
-void
-sipe_im_process_queue (struct sipe_account_data * sip, struct sip_session * session);
+sipe_im_process_queue(struct sipe_core_private *sipe_private,
+		      struct sip_session *session);
 
+/* sipe-notify? */
+void process_incoming_notify(struct sipe_core_private *sipe_private,
+			     struct sipmsg *msg,
+			     gboolean request,
+			     gboolean benotify);
 
 /*** THE BIG SPLIT END ***/
 
-#define SIPE_INVITE_TEXT "ms-text-format: %s; charset=UTF-8%s;ms-body=%s\r\n"
+#ifdef HAVE_GMIME
+/* pls. don't add multipart/related - it's not used in IM modality */
+#define SDP_ACCEPT_TYPES  "text/plain text/html image/gif multipart/alternative application/im-iscomposing+xml application/ms-imdn+xml text/x-msmsgsinvite"
+#else
+/* this is a rediculous hack as Pidgin's MIME implementastion doesn't support (or have bug) in multipart/alternative */
+/* OCS/OC won't use multipart/related so we don't advertase it */
+#define SDP_ACCEPT_TYPES  "text/plain text/html image/gif application/im-iscomposing+xml application/ms-imdn+xml text/x-msmsgsinvite"
+#endif
 
-#define SIPE_SEND_TYPING \
-"<?xml version=\"1.0\"?>"\
-"<KeyboardActivity>"\
-  "<status status=\"type\" />"\
-"</KeyboardActivity>"
+#define SIPE_INVITE_TEXT "ms-text-format: %s; charset=UTF-8%s;ms-body=%s\r\n"
 
 /**
  * Publishes categories.
